==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebButtonBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var WebButtonBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebButtonBaseDescriptionMetadata, _super);
    function WebButtonBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebButtonBaseDescriptionMetadata.b = function (a) {
        if (WebButtonBaseDescriptionMetadata.a == null) {
            WebButtonBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebButtonBaseDescriptionMetadata.c(WebButtonBaseDescriptionMetadata.a);
        }
        if (a.g(WebButtonBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(WebButtonBaseDescriptionMetadata.a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebButtonBaseDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ButtonBase");
        a.item("DisplayType", "(wc:Type)ExportedType:string:ButtonBaseType");
        a.item("DisplayType@names", "Button;Reset;Submit");
        a.item("Href", "String");
        a.item("Download", "String");
        a.item("Target", "ExportedType:string:ButtonBaseTarget");
        a.item("Target@names", "_blank;_parent;_self;_top");
        a.item("Rel", "String");
        a.item("Disabled", "Boolean");
        a.item("AriaLabel", "String");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
        a.item("ClickedRef", "EventRef::clicked");
        a.item("FocusRef", "EventRef::focus");
        a.item("BlurRef", "EventRef::blur");
    };
    WebButtonBaseDescriptionMetadata.d = function (a) {
        WebButtonBaseDescriptionMetadata.b(a);
        a.t("WebButtonBase", WebButtonBaseDescriptionMetadata.a);
    };
    WebButtonBaseDescriptionMetadata.$t = markType(WebButtonBaseDescriptionMetadata, 'WebButtonBaseDescriptionMetadata');
    WebButtonBaseDescriptionMetadata.a = null;
    return WebButtonBaseDescriptionMetadata;
}(Base));
export { WebButtonBaseDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebButtonBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var WebButtonBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebButtonBaseDescriptionMetadata, _super);
    function WebButtonBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebButtonBaseDescriptionMetadata.b = function (a) {
        if (WebButtonBaseDescriptionMetadata.a == null) {
            WebButtonBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebButtonBaseDescriptionMetadata.c(WebButtonBaseDescriptionMetadata.a);
        }
        if (a.j(WebButtonBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(WebButtonBaseDescriptionMetadata.a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebButtonBaseDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ButtonBase");
        a.item("DisplayType", "(wc:Type)ExportedType:string:ButtonBaseType");
        a.item("DisplayType@names", "Button;Reset;Submit");
        a.item("Href", "String");
        a.item("Download", "String");
        a.item("Target", "ExportedType:string:ButtonBaseTarget");
        a.item("Target@names", "_blank;_parent;_self;_top");
        a.item("Rel", "String");
        a.item("Disabled", "Boolean");
        a.item("AriaLabel", "String");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
        a.item("ClickedRef", "EventRef::clicked");
        a.item("FocusRef", "EventRef::focus");
        a.item("BlurRef", "EventRef::blur");
    };
    WebButtonBaseDescriptionMetadata.d = function (a) {
        WebButtonBaseDescriptionMetadata.b(a);
        a.z("WebButtonBase", WebButtonBaseDescriptionMetadata.a);
    };
    WebButtonBaseDescriptionMetadata.$t = markType(WebButtonBaseDescriptionMetadata, 'WebButtonBaseDescriptionMetadata');
    WebButtonBaseDescriptionMetadata.a = null;
    return WebButtonBaseDescriptionMetadata;
}(Base));
export { WebButtonBaseDescriptionMetadata };
